function startGame (lv) -- lv = level atual
lv=lv+1
--variaveis locais
local map -- stores tiledata
local mapWidth, mapHeight -- width and height in tiles
local mapX, mapY -- view x,y in tiles. can be a fractional value like 3.15.
local tilesDisplayWidth, tilesDisplayHeight -- number of tiles to show
local zoomX, zoomY
local tilesetImage
local tileSize -- size of tiles in pixels
local tileQuads = {} -- parts of the tileset used for different tiles
local tilesetSprite

require('camera')
require('menu')
--requerimentos q se alteram com o nivel
require('level'..lv..'/maze')
require('level'..lv..'/map')
require('level'..lv..'/player')

function love.load()
	--initial graphics setup
	love.graphics.setBackgroundColor(255, 255, 255)
	--set the background color to a nice blue
	love.graphics.setMode(800, 600, false, true, 0)
	--set the window dimensions to 800 by 600 with no fullscreen,
	--vsync on, and no antialiasing

	gamestate = 'menu'
	
	--Buttons
	button_spawn(370,380,'START','start')
	button_spawn(360,430,'OPTIONS','options')
	button_spawn(380,480,'EXIT','exit')
	
	--camera[
	width = love.graphics.getWidth()
	height = love.graphics.getHeight()
	camera:setBounds(0, 0, width, height)
	--]

	--Variaveis do mapa[
	setupMap()
	setupMapView()
	setupTileset()
	--]

  --menu screen
  menuScreen=love.graphics.newImage("images/menu.png")
	
  --animation1
  require("anal")
  bat=love.graphics.newImage("images/bat.png")
  bat:setFilter("nearest", "nearest")             --define the interpolation method used by love when it resizes the bat image
  animation = newAnimation(bat, 30, 30, 0.15, 5)   --create the animation object from the bat image, define the width and height, the delay between the frames

  --animation1
  bat2=love.graphics.newImage("images/bat2.png")
  bat2:setFilter("nearest", "nearest")
  animation2 = newAnimation(bat2, 30, 30, 0.15, 5)

  --fisicas
  love.physics.setMeter(64) --the height of a meter our worlds will be 64px
  world = love.physics.newWorld(0, 0*64, true)
  --create a world for the bodies to exist in with horizontal gravity of 0
  --and vertical gravity of 0
  world:setCallbacks(beginContact, endContact, preSolve, postSolve)
  persisting = 0 
  objects = {} -- table to hold all our physical objects

  --criando o "corpo" do jogador
  createPlayer ()

  -- Criando as paredes do labirinto
  mazeWalls ()

end

--funções do mapa[
function setupMap()
  --Pedras ao longo do mapa
  mapWidth = 60
  mapHeight = 40
  map = {}
  for x=1,mapWidth do
    map[x] = {}
    for y=1,mapHeight do
      map[x][y] = 0
    end
  end
  letsRock(map)
end

function setupMapView()
  mapX = 1
  mapY = 1
  tilesDisplayWidth = 26
  tilesDisplayHeight = 20
  zoomX = 2
  zoomY = 2
end

function setupTileset()
  tilesetImage = love.graphics.newImage( "images/tileset.png" )
  tilesetImage:setFilter("nearest", "linear") -- this "linear filter" removes some artifacts if we were to scale the tiles
  tileSize = 32
  tileSize = 32

  -- rock
  tileQuads[0] = love.graphics.newQuad(0 * tileSize, 0 * tileSize, tileSize, tileSize,
  tilesetImage:getWidth(), tilesetImage:getHeight())
  -- wall
  tileQuads[1] = love.graphics.newQuad(1 * tileSize, 0 * tileSize, tileSize, tileSize,
    tilesetImage:getWidth(), tilesetImage:getHeight())

  tilesetBatch = love.graphics.newSpriteBatch(tilesetImage, tilesDisplayWidth * tilesDisplayHeight)

  updateTilesetBatch()
end

function updateTilesetBatch()
	tilesetBatch:clear()
	for x=0, tilesDisplayWidth-1 do
		for y=0, tilesDisplayHeight-1 do
			tilesetBatch:addq(tileQuads[map[x+math.floor(mapX)][y+math.floor(mapY)]],
			x*tileSize, y*tileSize)
		end
	end
end  

function love.update(dt)
	mousex = love.mouse.getX()
	mousey = love.mouse.getY()
	if gamestate == 'menu' then
		button_check()
	end
	if gamestate=='playing' then
		world:update(dt) --this puts the world into motion
		animation:update(dt) --ask love to update the animation object, as much as dt seconds, on every frame
		animation2:update(dt)

		--here we are going to create some keyboard events

		if love.keyboard.isDown("right","left","up","down") then

			if love.keyboard.isDown("right") and love.keyboard.isDown("up") then --press the right arrow key to push the ball to the right
				objects.ball.body:setLinearVelocity(300, -300)
				move=2

			elseif love.keyboard.isDown("left") and love.keyboard.isDown( "up") then --press the left arrow key to push the ball to the left
				objects.ball.body:setLinearVelocity(-300, -300)
				move=1

			elseif love.keyboard.isDown("left") and love.keyboard.isDown( "down") then --press the up arrow key to set the ball in the air
				objects.ball.body:setLinearVelocity(-300, 300)
				move=1

			elseif love.keyboard.isDown("right") and love.keyboard.isDown( "down") then --press the down arrow key to set the ball in the air
				objects.ball.body:setLinearVelocity(300, 300)
				move=2

			elseif love.keyboard.isDown("right") then --press the right arrow key to push the ball to the right

				objects.ball.body:setLinearVelocity(300, 0)
				move=2

			elseif love.keyboard.isDown("left") then --press the left arrow key to push the ball to the left

				objects.ball.body:setLinearVelocity(-300, 0)
				move=1

			elseif love.keyboard.isDown("up") then --press the up arrow key to set the ball in the air

				objects.ball.body:setLinearVelocity(0, -300)

			elseif love.keyboard.isDown("down") then --press the down arrow key to set the ball in the air

				objects.ball.body:setLinearVelocity(0, 300)
			elseif love.keyboard.isDown("R") then --press the down arrow key to set the ball in the air
				lv=lv+1
				startGame (lv)
			end
		else
			objects.ball.body:setLinearVelocity(0,0)
		end
	
		camera:setPosition(objects.ball.body:getX() - width / 2, objects.ball.body:getY() - height / 2)
	end
end

function love.draw()
	if gamestate =='menu' then 
		love.graphics.setColor(255, 255, 255)
		love.graphics.draw(menuScreen, 0, 0 )
		button_draw() 
	end

	if gamestate=='playing' then
		camera:set()

		--drawing the map
		love.graphics.setColor(200, 200, 200)
		mapPositionX= math.floor(-zoomX*(mapX%1)*tileSize)
		mapPositionY= math.floor(-zoomY*(mapY%1)*tileSize)
		love.graphics.draw(tilesetBatch,mapPositionX, mapPositionY,0, zoomX, zoomY)
		love.graphics.print(" Press ESC to back to menu. ", 0, 0)

		--Drawing the ball
		drawPlayer ()

		--draw the animation object at (800/2-70,600/2-80), upright (0 degree), and scale it up 5 times
		love.graphics.setColor(250, 250, 250)
		if (move == 1) then
			animation:draw(objects.ball.body:getX()-60, objects.ball.body:getY()-60, 0, 5)
		else
			animation2:draw(objects.ball.body:getX()-90, objects.ball.body:getY()-60, 0, 5)
		end

		--Desenhando as paredes (essa função é opcional, pois se você não desenhá-las elas se construirão igual, mas invisíveis.
		--drawMaze ()
  
		camera:unset()
	end
end

	function love.keyreleased(key)
		if key == "escape" then
			gamestate = 'menu'   -- back to menu
		end
	end

	function math.clamp(x, min, max)
		return x < min and min or (x > max and max or x)
	end
	
	function love.mousepressed(x,y)
		if gamestate == 'menu' then 
			button_click(x,y)
		end
	end
end